==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Content/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_PREVIOUS","W@");
define("_NEXT","U@");


define("_PAGE","");
define("_DEACTIVATE","");
define("_ACTIVATE","");
define("_PUBLISHEDON","o");
define("_PAGESLIST","eC");
define("_LISTOFCONTENT","ioeb ");
define("_YOURADMINLIST","zO޲z: UO|}񪺺e:");
define("_COPYRIGHT","Copyright &copy; by $sitename. All Right Reserved.");
define("_CONTENTCATEGORIES","Available Content Categories");
define("_NONCLASSCONT","Non Categorized Content");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Content/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_PREVIOUS","W@");
define("_NEXT","U@");


define("_PAGE","");
define("_DEACTIVATE","");
define("_ACTIVATE","");
define("_PUBLISHEDON","o");
define("_PAGESLIST","eC");
define("_LISTOFCONTENT","ioeb ");
define("_YOURADMINLIST","zO޲z: UO|}񪺺e:");
define("_COPYRIGHT","Copyright &copy; by");
define("_COPYRIGHT2","All Right Reserved.");
define("_CONTENTCATEGORIES","Available Content Categories");
define("_NONCLASSCONT","Non Categorized Content");

?>
